@@ -10,5 +10,7 @@ GtkWidget *create_listeners_selector(char *selected_listener_uri,
 				     char *filename);
 GtkWidget *create_stations_selector(char *selected_station_uri,
 				    char *filename);
+GtkWidget *create_streams_selector(char *selected_streams_uri,
+				   char *filename);
 
 #endif				/* GIRL_GUI_H */
